/* ide-webkit-util.h
 *
 * Copyright 2022 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <libide-webkit-api.h>

G_BEGIN_DECLS

typedef enum
{
  IDE_WEBKIT_SECURITY_LEVEL_NONE,
  IDE_WEBKIT_SECURITY_LEVEL_LOCAL_PAGE,
  IDE_WEBKIT_SECURITY_LEVEL_STRONG_SECURITY,
  IDE_WEBKIT_SECURITY_LEVEL_UNACCEPTABLE_CERTIFICATE,
  IDE_WEBKIT_SECURITY_LEVEL_TO_BE_DETERMINED,
} IdeWebkitSecurityLevel;

char                   *ide_webkit_util_normalize_address  (const char    *input_address);
IdeWebkitSecurityLevel  ide_webkit_util_get_security_level (WebKitWebView *web_view);

G_END_DECLS
